@@ -30,15 +30,26 @@ namespace OPNsense\HAProxy\Migrations;
 
 use OPNsense\Base\BaseModelMigration;
 
-class M2_3_0 extends BaseModelMigration
+class M2_6_0 extends BaseModelMigration
 {
     public function run($model)
     {
-        // Persistence is a separate option now.
-        foreach ($model->getNodeByReference('backends.backend')->iterateItems() as $backend) {
-            if (isset($backend->stickiness_pattern)) {
-                  $backend->persistence = 'sticktable';
+        // Migrate old stats user:password entries to new user management feature
+        if (!empty((string)$model->general->stats->users)) {
+            // Add new user for each entry
+            $UUIDlist = array();
+            foreach (explode(',', (string)$model->general->stats->users) as $statsuser) {
+                $olddata = explode(':', $statsuser, 2);
+                $userNode = $model->users->user->Add();
+                $userNode->name = (string)$olddata[0];
+                $userNode->description = 'stats user';
+                $userNode->password = (string)$olddata[1];
+                $userNode->enabled = 1;
+                $UUIDlist[] = $userNode->getAttributes()['uuid'];
             }
+
+            // Add collected UUIDs to new list of allowed users
+            $model->general->stats->allowedUsers = (string)implode(',', $UUIDlist);
         }
     }
 }
